@@ -30,9 +30,11 @@ import org.gcube.portlets.user.tdwx.client.model.grid.DataRowColumnConfig;
 import org.gcube.portlets.user.tdwx.client.model.grid.DataRowModelKeyProvider;
 import org.gcube.portlets.user.tdwx.client.model.grid.DataRowPagingReader;
 import org.gcube.portlets.user.tdwx.client.model.util.ColumnConfigGenerator;
+import org.gcube.portlets.user.tdwx.client.style.DefaultRowStyle;
 import org.gcube.portlets.user.tdwx.client.util.ColumnPositionComparator;
 import org.gcube.portlets.user.tdwx.client.util.PagingLoadUrlEncoder;
 import org.gcube.portlets.user.tdwx.shared.ServletParameters;
+import org.gcube.portlets.user.tdwx.shared.StaticFilterInformation;
 import org.gcube.portlets.user.tdwx.shared.model.ColumnDefinition;
 import org.gcube.portlets.user.tdwx.shared.model.ColumnKey;
 import org.gcube.portlets.user.tdwx.shared.model.ColumnType;
@@ -102,7 +104,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 	protected ToolBar toolBar;
 	// protected GridInlineEditing<DataRow> editing;
 	protected TableDefinition tableDefinition;
-
+	
 	protected VerticalLayoutContainer container;
 
 	protected ExtendedLiveGridView liveGridView;
@@ -112,6 +114,8 @@ public class TabularDataXGridPanel extends ContentPanel {
 	protected PagingLoader<FilterPagingLoadConfig, PagingLoadResult<DataRow>> loader;
 
 	protected ExtendedGridFilters<DataRow> gridFilters;
+	
+	protected ArrayList<StaticFilterInformation> staticFilters;
 
 	protected TableViewConfig tableViewConfig;
 
@@ -121,6 +125,10 @@ public class TabularDataXGridPanel extends ContentPanel {
 	protected Map<String, ColumnKey> keys;
 
 	private String visibleOnlyColumn;
+	
+	protected boolean errorNotColored=false;
+	
+	
 
 	/**
 	 * @param eventBus
@@ -183,6 +191,24 @@ public class TabularDataXGridPanel extends ContentPanel {
 		return tableDefinition;
 	}
 
+	/**
+	 * Get static filters
+	 * 
+	 * @return
+	 */
+	public ArrayList<StaticFilterInformation> getStaticFilters() {
+		return staticFilters;
+	}
+
+	/**
+	 * Set static filters
+	 * 
+	 * @param staticFilters
+	 */
+	public void setStaticFilters(ArrayList<StaticFilterInformation> staticFilters) {
+		this.staticFilters = staticFilters;
+	}
+	
 	/**
 	 * Returns the selected row.
 	 * 
@@ -241,6 +267,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 	}
 	
 	
+
 	/**
 	 * 
 	 * 
@@ -382,6 +409,24 @@ public class TabularDataXGridPanel extends ContentPanel {
 		visibleOnlyColumn = columnLocalId;
 
 	}
+	
+	/**
+	 * 
+	 * @return
+	 */
+	public boolean isErrorNotColored() {
+		return errorNotColored;
+	}
+	
+	/**
+	 * 
+	 * @param errorNotColored if true set background withe for rows with error
+	 */
+	public void setErrorNotColored(boolean errorNotColored) {
+		Log.debug("ErrorNotColored set :"+errorNotColored);
+		this.errorNotColored = errorNotColored;
+	}
+	
 
 	/**
 	 * 
@@ -660,7 +705,7 @@ public class TabularDataXGridPanel extends ContentPanel {
 
 			HttpProxy<FilterPagingLoadConfig> proxy = new HttpProxy<FilterPagingLoadConfig>(
 					builder);
-			proxy.setWriter(new PagingLoadUrlEncoder());
+			proxy.setWriter(new PagingLoadUrlEncoder(staticFilters));
 
 			loader = new PagingLoader<FilterPagingLoadConfig, PagingLoadResult<DataRow>>(
 					proxy, reader) {
@@ -779,13 +824,23 @@ public class TabularDataXGridPanel extends ContentPanel {
 		}
 
 		if (tableViewConfig != null) {
+			Log.debug("Use specific grid View");
 			if (tableViewConfig.getRowStyleProvider() != null) {
 				grid.getView().setViewConfig(
 						new TabularDataGridViewConfig(tableViewConfig,
 								tableDefinition));
 			}
 		} else {
-			grid.getView().setViewConfig(null);
+			Log.debug("Use default grid View");
+			tableViewConfig= new TableViewConfig();
+			Log.debug("Error Not Colored: "+errorNotColored);
+			DefaultRowStyle rowStyle=new DefaultRowStyle(errorNotColored);
+			
+			tableViewConfig.setRowStyleProvider(rowStyle);
+			grid.getView().setViewConfig(
+					new TabularDataGridViewConfig(tableViewConfig,
+							tableDefinition));
+			//	grid.getView().setViewConfig(null);
 		}
 
 		container.forceLayout();
@@ -798,6 +853,10 @@ public class TabularDataXGridPanel extends ContentPanel {
 		});
 
 		eventBus.fireEvent(new GridReadyEvent());
+		
+		
+		
+		
 	}
 
 	/**
